@@ -1,9 +1,9 @@
 #!/usr/local/bin/perl
 eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}' if 0;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
-use WWW::ShopBot qw(list_drivers);
+use WWW::ShopBot qw(list_drivers list_drivers_paths);
 use Data::Dumper;
 
 sub list {
@@ -11,6 +11,11 @@ sub list {
     print map({"- $_\n"} @drivers), "\n", scalar(@drivers)." driver(s) found\n"; 
 }
 
+sub list_paths {
+    @drivers = list_drivers_paths;
+    print map({"- $_\n"} @drivers), "\n", scalar(@drivers)." driver(s) found\n";
+}
+
 sub newdriver {
     my $dn = shift;
     my $dd = shift || '.';
@@ -77,6 +82,7 @@ sub help { system "perldoc $0 | less" }
 my %cmdtbl =
     (
      list => \&list,
+     list_paths => \&list_paths,
      newdriver => \&newdriver,
      action => \&action,
      help => \&help,
@@ -96,6 +102,8 @@ shopbot.pl - Shopping Agent
 
  % shopbot.pl list
 
+ % shopbot.pl list_path
+
  % shopbot.pl newdriver COM::Shhhhhh
 
  % shopbot.pl query drivers
@@ -110,6 +118,12 @@ It is a script for you to list existent shopbot drivers, generate driver's templ
 
  % shopbot.pl list
 
+Or use
+
+ % shopbot.pl list_paths
+
+It prints names of existent drivers with their paths.
+
 =head2 Generate driver template
 
  % shopbot.pl newdriver driver_name [ dest_dir ]
